import { SystemHealthAlertsBase } from '../foundation-system-health-alerts-base';
import type { ServerStatusConfig, SystemHealthAlertsServerAvailableStatus, ServerStatusMessageItem } from './main.types';
/**
 * The `SystemHealthAlertsServer` component is designed to monitor and display the status of server in real-time.
 *
 * @alpha
 */
export declare class SystemHealthAlertsServer extends SystemHealthAlertsBase {
    autoClose: ServerStatusConfig['autoClose'];
    closeTimeout: ServerStatusConfig['closeTimeout'];
    displayOnChange: boolean;
    titleRestored: string;
    messageRestored: string;
    titleFailed: string;
    messageFailed: string;
    currentServerStatus: SystemHealthAlertsServerAvailableStatus;
    currentServerStatusChanged(oldServerStatus: SystemHealthAlertsServerAvailableStatus, newServerStatus: SystemHealthAlertsServerAvailableStatus): void;
    display: boolean;
    systemStatusChanged(ignore: any, newStatus: any): void;
    constructor();
    closeHandler: (event: any) => void;
    private setServerStatus;
    getCurrentMessage(): ServerStatusMessageItem | undefined;
}
/**
 * ZeroSystemHealthAlertsServer.
 *
 * @remarks
 * A zero version that pre-registers zero components and uses the zero design system.
 *
 * @example
 * ```ts
 * import { ZeroSystemHealthAlertsServer } from '@genesislcap/foundation-system-health-alerts';
 * ...
 * ZeroSystemHealthAlertsServer
 * ```
 *
 * @example Load the micro frontend on-demand
 * ```ts

 *   const { ZeroSystemHealthAlertsServer } = await import('@genesislcap/foundation-system-health-alerts');
 *   return ZeroSystemHealthAlertsServer;
 * },
 * ```
 *
 * @public
 */
export declare class ZeroSystemHealthAlertsServer extends SystemHealthAlertsServer {
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    protected loadRemotes(): Promise<void>;
}
//# sourceMappingURL=main.d.ts.map