import { __awaiter, __decorate } from "tslib";
import { getNetworkMonitor } from '@genesislcap/foundation-comms';
import { FASTElement, observable, Observable } from '@microsoft/fast-element';
import { logger } from '../utils';
import { SYSTEM_HEALTH_ALERTS_EVENTS_NAMES as EVENTS_NAMES } from './main.config';
/**
 * The `SystemHealthAlertsBase` component is designed to monitor and display the status of server in real-time.
 *
 * @alpha
 */
export class SystemHealthAlertsBase extends FASTElement {
    constructor() {
        super(...arguments);
        this.monitor = getNetworkMonitor();
        this.rootEventsListeners = [];
    }
    connectedCallback() {
        super.connectedCallback();
        // Subscribe to changes in monitor.status - this will trigger the handleChange method
        Observable.getNotifier(this.monitor).subscribe(this, 'status');
        this.startMonitoring();
    }
    handleChange() {
        this.systemStatus = this.monitor.status;
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        this.stopMonitoring();
    }
    startMonitoring() {
        return __awaiter(this, void 0, void 0, function* () {
            logger.info('start monitoring');
            // handle root events listeners
            this.rootEventsListeners.forEach(({ key, action }) => {
                this.addEventListener(key, action);
            });
            this.$emit(EVENTS_NAMES.MONITOR_START);
        });
    }
    stopMonitoring() {
        logger.info('stop monitoring');
        // handle remove root events listeners
        this.rootEventsListeners.forEach(({ key, action }) => {
            this.removeEventListener(key, action);
        });
        this.$emit(EVENTS_NAMES.MONITOR_STOP);
    }
}
__decorate([
    observable
], SystemHealthAlertsBase.prototype, "monitor", void 0);
__decorate([
    observable
], SystemHealthAlertsBase.prototype, "systemStatus", void 0);
